#ifndef CURVE_H
#define CURVE_H

// includes
//----------
#include "point.h"

// STL C++
#include <vector>
using namespace std;


/*!
* CLASS
* Curve
*
* Base class to define the curves geometric objects. 
*
*/
class Curve
{
 public:
  enum CurveType{ LINE, POLYLINE, QUADBEZIER, CUBICBEZIER, CIRCLE, CIRCLEARC };
  Curve();
  virtual ~Curve();
  virtual int getType() = 0;
  virtual void addPoint( double _x, double _y ) = 0;
  virtual Point getPoint( double _t ) = 0;
  virtual bool isPossible() = 0;
  virtual bool isUnlimited() = 0;
  virtual vector<Point> getPoints() = 0;
  virtual vector<Point> getPointsToDraw() = 0;
  virtual vector<Point> getPointsToDraw( Point _pt ) = 0;
  virtual double closestPoint( double* x, double* y ) = 0;
  virtual void getBoundBox( double* xmin, double* xmax,
                            double* ymin, double* ymax ) = 0;
  int getNumberOfPoints() { return m_nPts; };
  void setSelected( bool _select ) { m_selected = _select; };
  bool isSelected() { return m_selected; };

 protected:
  int m_nPts;
  bool m_selected;
};

#endif // CURVE_H
