#include "curvecollector.h"
#include "curves/line.h"

//-------------------------------------------------------------------------
CurveCollector::CurveCollector()
: m_curve( 0 )
, m_tempPt( 2 )
{
 curve_type = Curve::LINE;
}
//-------------------------------------------------------------------------

//-------------------------------------------------------------------------
CurveCollector::~CurveCollector()
{
 if( m_curve != 0 )
  delete m_curve;
}
//-------------------------------------------------------------------------

//-------------------------------------------------------------------------
void 
CurveCollector::setCurveType( int _type )
{
 if( curve_type == _type )
  return;

 switch( _type )
 {
  default:
  case Curve::LINE:
   curve_type = Curve::LINE;
   break;
  }
}
//-------------------------------------------------------------------------

//-------------------------------------------------------------------------
void 
CurveCollector::startCurveCollection()
{
 if( m_curve != 0 )
  delete m_curve;

 switch( curve_type )
 {
  default:
  case Curve::LINE:
  {
   m_curve = new Line();
   break;
  }
 }
}
//-------------------------------------------------------------------------

//-------------------------------------------------------------------------
void 
CurveCollector::endCurveCollection()
{
 m_curve = 0;
}
//-------------------------------------------------------------------------

//-------------------------------------------------------------------------
bool 
CurveCollector::isActive()
{
 if( m_curve != 0 )
 {
  return true;
 }
 return false;
}
//-------------------------------------------------------------------------

//-------------------------------------------------------------------------
bool 
CurveCollector::isCollecting()
{
 if( m_curve != 0 )
 {
  if( m_curve->getNumberOfPoints() > 0 )
  {
   return true;
  }
 }
 return false;
}
//-------------------------------------------------------------------------

//-------------------------------------------------------------------------
bool 
CurveCollector::hasFinished()
{
 if( m_curve != 0 )
 {
  if( m_curve->isPossible() )
  {
   return true;
  }
 }
 return false;
}
//-------------------------------------------------------------------------

//-------------------------------------------------------------------------
bool 
CurveCollector::isUnlimited()
{
 if( m_curve != 0 )
 {
  if( m_curve->isUnlimited() )
  {
   return true;
  }
 }
 return false;
}
//-------------------------------------------------------------------------

//-------------------------------------------------------------------------
int 
CurveCollector::insertPoint(double _x, double _y)
{
 m_curve->addPoint(_x,_y);
 return 1;
}
//-------------------------------------------------------------------------

//-------------------------------------------------------------------------
int 
CurveCollector::addTempPoint(double _x, double _y)
{
 m_tempPt.setCoords(_x,_y);
 return 1;
}
//-------------------------------------------------------------------------

//-------------------------------------------------------------------------
vector<Point> 
CurveCollector::getDrawPoints()
{
 vector<Point> pts = m_curve->getPointsToDraw( m_tempPt );
 return pts;
}
//-------------------------------------------------------------------------

//-------------------------------------------------------------------------
vector<Point> 
CurveCollector::getPoints()
{
 vector<Point> pts = m_curve->getPoints();
 return pts;
}
//-------------------------------------------------------------------------

//-------------------------------------------------------------------------
void 
CurveCollector::getBoundBox( double* xmin, double* xmax, double* ymin, double* ymax )
{
 if( !m_curve )
  return;
 m_curve->getBoundBox(xmin, xmax, ymin, ymax);
}
//-------------------------------------------------------------------------

//-------------------------------------------------------------------------
void
CurveCollector::reset()
{
 if( m_curve != 0 )
  delete m_curve;
 m_curve = 0;
}
//-------------------------------------------------------------------------

//-------------------------------------------------------------------------
void
CurveCollector::kill()
{
 if( m_curve != 0 )
  delete m_curve;
 delete this;
}
//-------------------------------------------------------------------------
