#include "geommodel.h"

//--------------------------------------------------------------------
GeomModel::GeomModel()
{
}
//--------------------------------------------------------------------

//--------------------------------------------------------------------
GeomModel::~GeomModel()
{
}
//--------------------------------------------------------------------

//--------------------------------------------------------------------
void 
GeomModel::insertCurve( Curve* curve )
{
 m_curves.push_back(curve);
}
//--------------------------------------------------------------------

//--------------------------------------------------------------------
void 
GeomModel::delSelectedCurves()
{
 bool curveRemoved;
 do
 {
  curveRemoved = false;
  for(int i = 0; i < m_curves.size(); i++)
  {
   if( m_curves[i]->isSelected() )
   {
    m_curves.erase(m_curves.begin()+i);
    curveRemoved = true;
    break;
   }
  }
 } while( curveRemoved );
}
//--------------------------------------------------------------------

//--------------------------------------------------------------------
void 
GeomModel::getBoundBox(double* xmin, double* xmax, double* ymin, double* ymax)
{
 if(m_curves.size() < 1)
 {
  *xmin =  0.0;
  *xmax = 10.0;
  *ymin =  0.0;
  *ymax = 10.0;
  return;
 }

 m_curves[0]->getBoundBox(xmin, xmax, ymin, ymax);
 for(int i = 1; i < m_curves.size(); i++)
 {
  double xmin_c, xmax_c, ymin_c, ymax_c;
  m_curves[i]->getBoundBox(&xmin_c, &xmax_c, &ymin_c, &ymax_c);
  if(xmin_c < *xmin)
   *xmin = xmin_c;
  if(xmax_c > *xmax)
   *xmax = xmax_c;
  if(ymin_c < *ymin)
   *ymin = ymin_c;
  if(ymax_c > *ymax)
   *ymax = ymax_c;
 }
}
//--------------------------------------------------------------------

//--------------------------------------------------------------------
void 
GeomModel::selectPick( double x, double y, double _tol, bool shiftkey )
{
 if(m_curves.size() < 1)
  return;

 double xClst, yClst;
 int id_target = -1;
 double dmin = _tol;
 for(int i = 0; i < m_curves.size(); i++)
 {
  // Compute distance between given point and curve and
  // update minimum distance
  xClst = x;
  yClst = y;
  double d = m_curves[i]->closestPoint( &xClst, &yClst );
  if(d < dmin)
  {
   dmin = d;
   id_target = i;
  }
 }

 // Revert selection of picked curve
 if(id_target > -1)
 {
  if( m_curves[id_target]->isSelected() )
  {
   m_curves[id_target]->setSelected(false);
  } 
  else
  {
   m_curves[id_target]->setSelected(true);
  }
 }

 if( !shiftkey )
 {
  // If shift key is not pressed, unselect all curves except 
  // the picked one (if there was one selected)
  for(int i = 0; i < m_curves.size(); i++)
  {
   if( i != id_target )
    m_curves[i]->setSelected(false);
  }
 }
}
//--------------------------------------------------------------------

//--------------------------------------------------------------------
void 
GeomModel::selectFence( double xmin, double xmax,
                        double ymin, double ymax, bool shiftkey )
{
 if(m_curves.size() < 1)
  return;

 double xmin_c, xmax_c, ymin_c, ymax_c;
 bool inFence;
 for(int i = 0; i < m_curves.size(); i++)
 {
  m_curves[i]->getBoundBox(&xmin_c, &xmax_c, &ymin_c, &ymax_c);
  if( (xmin_c < xmin) || (xmax_c > xmax) ||
      (ymin_c < ymin) || (ymax_c > ymax) )
   inFence = false;
  else
   inFence = true;

  if( inFence )
  {
   // Select curve inside fence
   m_curves[i]->setSelected(true);
  }
  else
  {
  // If shift key is not pressed, unselect curve outside fence
   if( !shiftkey )
    m_curves[i]->setSelected(false);
  }
 }
}
//--------------------------------------------------------------------
